package com.loganmagnan.unlimiteditems.listeners;

import com.loganmagnan.unlimiteditems.UnlimitedItems;
import com.loganmagnan.unlimiteditems.playerdata.PlayerData;
import com.loganmagnan.unlimiteditems.playerdata.PlayerSettings;
import org.bukkit.Material;
import org.bukkit.entity.Entity;
import org.bukkit.entity.Player;
import org.bukkit.event.EventHandler;
import org.bukkit.event.Listener;
import org.bukkit.event.entity.EntityPickupItemEvent;
import org.bukkit.inventory.ItemStack;

public class EntityPickupItemListener implements Listener {

    private UnlimitedItems main = UnlimitedItems.getInstance();

    @EventHandler
    public void onEntityPickupItem(EntityPickupItemEvent event) {
        Entity entity = event.getEntity();

        if (!(entity instanceof Player)) {
            return;
        }

        Player player = (Player) entity;

        PlayerData playerData = this.main.getPlayerDataManager().getPlayerData(player.getUniqueId());

        PlayerSettings playerSettings = playerData.getPlayerSettings();

        if (!playerSettings.isUnlimitedItems()) {
            return;
        }

        ItemStack itemStackOne = event.getItem().getItemStack();

        event.setCancelled(true);
        event.getItem().remove();

        if (player.getInventory().contains(itemStackOne.getType())) {
            int amount = this.getMaterialAmount(player, itemStackOne.getType());

            ItemStack itemStackTwo = new ItemStack(itemStackOne.getType(), itemStackOne.getAmount() + amount);

            this.removeMaterial(player, itemStackOne.getType(), amount);

            player.getInventory().addItem(itemStackTwo);
        } else {
            player.getInventory().addItem(itemStackOne);
        }
    }

    public int getMaterialAmount(Player player, Material material) {
        int amount = 0;

        for (ItemStack item : player.getInventory().getContents()) {
            if (item != null && item.getType() == material) {
                amount += item.getAmount();
            }
        }

        return amount;
    }

    public void removeMaterial(Player player, Material material, int amount) {
        ItemStack[] contents = player.getInventory().getContents();

        for (int i = 0; i < contents.length; i++) {
            ItemStack item = contents[i];

            if (item != null && item.getType() == material && amount > 0) {
                int itemAmount = item.getAmount();

                if (itemAmount <= amount) {
                    amount -= itemAmount;
                    player.getInventory().setItem(i, null);

                } else {
                    item.setAmount(itemAmount - amount);

                    amount = 0;
                }
            }
        }

        player.updateInventory();
    }
}